@@ -139,6 +139,7 @@ class VerifyPhoneForm(forms.Form):
 class UserChangeForm(BaseUserChangeForm):
     class Meta(BaseUserChangeForm.Meta):
         model = UserModel
+        fields = ('username', 'first_name', 'last_name')
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -152,7 +153,7 @@ class UpdateUserDataForm(UserChangeForm):
     def clean_first_name(self):
         first_name = self.cleaned_data.get('first_name', None)
         if not first_name:
-            raise ValidationError(_("Please Enter the new first"), code="required")
+            raise ValidationError(_("Please Enter the first name"), code="required")
 
         return first_name
 
