@@ -11,7 +11,7 @@ from django.contrib.auth.mixins import LoginRequiredMixin
 from django.contrib.auth.views import LoginView as BaseLoginView
 from django.shortcuts import render, redirect
 from django.urls import reverse
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.http import urlsafe_base64_decode
 from django.utils.timezone import now
 from django.utils.translation import gettext as _
@@ -204,7 +204,7 @@ class ResendPhoneConfirmationView(LoginRequiredMixin, View):
 class VerifyEmailView(LoginRequiredMixin, View):
     def get(self, request, uidb64, token):
         try:
-            uid = force_text(urlsafe_base64_decode(uidb64))
+            uid = force_str(urlsafe_base64_decode(uidb64))
             user = UserModel.objects.get(pk=uid)
         except(TypeError, ValueError, OverflowError, UserModel.DoesNotExist):
             user = None
